src/gui/dialogs/qmessagebox.cpp
branchRCL_3
changeset 4 3b1da2848fc7
parent 3 41300fa6a67c
child 8 3f74d0d4af4c
--- a/src/gui/dialogs/qmessagebox.cpp	Tue Feb 02 00:43:10 2010 +0200
+++ b/src/gui/dialogs/qmessagebox.cpp	Fri Feb 19 23:40:16 2010 +0200
@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -58,6 +58,7 @@
 #include <QtGui/qtextdocument.h>
 #include <QtGui/qapplication.h>
 #include <QtGui/qtextedit.h>
+#include <QtGui/qtextbrowser.h>
 #include <QtGui/qmenu.h>
 #include "qdialog_p.h"
 #include <QtGui/qfont.h>
@@ -188,8 +189,8 @@
     bool autoAddOkButton;
     QAbstractButton *detectedEscapeButton;
     QLabel *informativeLabel;
-#ifdef Q_OS_SYMBIAN
-    QTextEdit *textEdit;
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5)
+    QTextBrowser *textBrowser;
 #endif
     QPointer<QObject> receiverToDisconnectOnClose;
     QByteArray memberToDisconnectOnClose;
@@ -1726,7 +1727,7 @@
         "to comply with the terms of the GNU GPL version 3.0.</p>"
         "<p>Please see <a href=\"http://qt.nokia.com/products/licensing\">qt.nokia.com/products/licensing</a> "
         "for an overview of Qt licensing.</p>"
-        "<p>Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).</p>"
+        "<p>Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).</p>"
         "<p>Qt is a Nokia product. See <a href=\"http://qt.nokia.com/\">qt.nokia.com</a> "
         "for more information.</p>"
         );
@@ -2462,12 +2463,12 @@
 #endif
         label->setWordWrap(true);
         QGridLayout *grid = static_cast<QGridLayout *>(layout());
-#ifdef Q_OS_SYMBIAN
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5)
         label->hide();
-        QTextEdit *textEdit = new QTextEdit(this);
-        textEdit->setReadOnly(true);
-        grid->addWidget(textEdit, 1, 1, 1, 1);
-        d->textEdit = textEdit;
+        QTextBrowser *textBrowser = new QTextBrowser(this);
+        textBrowser->setOpenExternalLinks(true);
+        grid->addWidget(textBrowser, 1, 1, 1, 1);
+        d->textBrowser = textBrowser;
 #else
         grid->addWidget(label, 1, 1, 1, 1);
 #endif
@@ -2475,9 +2476,9 @@
     }
     d->informativeLabel->setText(text);
 
-#ifdef Q_OS_SYMBIAN
-    //We need to put the informative label inside textEdit to enable scrolling of long texts.
-    d->textEdit->setText(d->informativeLabel->text());
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5)
+    //We need to put the informative label inside textBrowser to enable scrolling of long texts.
+    d->textBrowser->setText(d->informativeLabel->text());
 #endif
 
     d->updateSize();